==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QByteArrayMatcher_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qbytearraymatcher.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QByteArrayMatcher(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QByteArrayMatcher")
    QByteArrayMatcher *_ptr = reinterpret_cast<QByteArrayMatcher *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QByteArrayMatcher()
void __qt_construct_QByteArrayMatcher_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QByteArrayMatcher()")
    Q_UNUSED(__java_arguments)
    QByteArrayMatcher *__qt_this = new(__qtjambi_ptr) QByteArrayMatcher();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QByteArrayMatcher(QByteArray)
void __qt_construct_QByteArrayMatcher_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QByteArrayMatcher(QByteArray)")
    jobject pattern0 = __java_arguments[0].l;
    const QByteArray& __qt_pattern0 = qtjambi_cast<const QByteArray& >(__jni_env, pattern0);
    QByteArrayMatcher *__qt_this = new(__qtjambi_ptr) QByteArrayMatcher(__qt_pattern0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QByteArrayMatcher(QByteArrayMatcher)
void __qt_construct_QByteArrayMatcher_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QByteArrayMatcher(QByteArrayMatcher)")
    jobject other0 = __java_arguments[0].l;
    const QByteArrayMatcher& __qt_other0 = qtjambi_cast<const QByteArrayMatcher& >(__jni_env, other0);
    QByteArrayMatcher *__qt_this = new(__qtjambi_ptr) QByteArrayMatcher(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QByteArrayMatcher
void __qt_destruct_QByteArrayMatcher(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QByteArrayMatcher")
    reinterpret_cast<QByteArrayMatcher*>(ptr)->~QByteArrayMatcher();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QByteArrayMatcher::QByteArrayMatcher()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_initialize_1native__Lio_qt_core_QByteArrayMatcher_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArrayMatcher::QByteArrayMatcher()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArrayMatcher_0, sizeof(QByteArrayMatcher), typeid(QByteArrayMatcher), false, &deleter_QByteArrayMatcher, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QByteArrayMatcher::QByteArrayMatcher(QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_initialize_1native__Lio_qt_core_QByteArrayMatcher_2Lio_qt_core_QByteArray_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject pattern0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArrayMatcher::QByteArrayMatcher(QByteArray)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = pattern0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArrayMatcher_1, sizeof(QByteArrayMatcher), typeid(QByteArrayMatcher), false, &deleter_QByteArrayMatcher, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QByteArrayMatcher::QByteArrayMatcher(QByteArrayMatcher)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_initialize_1native__Lio_qt_core_QByteArrayMatcher_2Lio_qt_core_QByteArrayMatcher_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArrayMatcher::QByteArrayMatcher(QByteArrayMatcher)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArrayMatcher_2, sizeof(QByteArrayMatcher), typeid(QByteArrayMatcher), false, &deleter_QByteArrayMatcher, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QByteArrayMatcher::indexIn(QByteArray,int)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_indexIn_1native_1cref_1QByteArray_1int_1constfct__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID ba0,
 jint from1)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::indexIn(QByteArray,int)const", __qt_this)
        const QByteArray& __qt_ba0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(ba0);
        __java_return_value = __qt_this->indexIn(__qt_ba0, static_cast<int>(from1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArrayMatcher::operator=(QByteArrayMatcher)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_assign_1native_1cref_1QByteArrayMatcher__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::operator=(QByteArrayMatcher)", __qt_this)
        const QByteArrayMatcher& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QByteArrayMatcher>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QByteArrayMatcher::operator==(QByteArrayMatcher,QByteArrayMatcher)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_equals_1native_1cref_1QByteArrayMatcher__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::operator==(QByteArrayMatcher,QByteArrayMatcher)", __qt_this)
        const QByteArrayMatcher& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QByteArrayMatcher>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArrayMatcher::pattern()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_pattern_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::pattern()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->pattern();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArrayMatcher::setPattern(QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_setPattern_1native_1cref_1QByteArray__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pattern0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::setPattern(QByteArray)", __qt_this)
        const QByteArray& __qt_pattern0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(pattern0);
        __qt_this->setPattern(__qt_pattern0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QByteArrayMatcher(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QByteArrayMatcher>("QByteArrayMatcher", "io/qt/core/QByteArrayMatcher");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QByteArrayMatcher, {
        ConstructorInfo(&__qt_construct_QByteArrayMatcher_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QByteArrayMatcher_1, "Lio/qt/core/QByteArray;")
       ,ConstructorInfo(&__qt_construct_QByteArrayMatcher_2, "Lio/qt/core/QByteArrayMatcher;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QByteArrayMatcher);
    registerMetaType<QByteArrayMatcher>("QByteArrayMatcher");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QByteArrayMatcher_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qbytearraymatcher.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QByteArrayMatcher(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QByteArrayMatcher")
    QByteArrayMatcher *_ptr = reinterpret_cast<QByteArrayMatcher *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QByteArrayMatcher()
void __qt_construct_QByteArrayMatcher(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QByteArrayMatcher()")
    Q_UNUSED(__java_arguments)
    QByteArrayMatcher *__qt_this = new(__qtjambi_ptr) QByteArrayMatcher();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QByteArrayMatcher::QByteArrayMatcher()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_initialize_1native__Lio_qt_core_QByteArrayMatcher_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArrayMatcher::QByteArrayMatcher()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArrayMatcher, sizeof(QByteArrayMatcher), typeid(QByteArrayMatcher), false, &deleter_QByteArrayMatcher, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QByteArrayMatcher(QByteArray)
void __qt_construct_QByteArrayMatcher_cref_QByteArray(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QByteArrayMatcher(QByteArray)")
    jobject pattern0 = __java_arguments[0].l;
    const QByteArray& __qt_pattern0 = qtjambi_cast<const QByteArray& >(__jni_env, pattern0);
    QByteArrayMatcher *__qt_this = new(__qtjambi_ptr) QByteArrayMatcher(__qt_pattern0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QByteArrayMatcher::QByteArrayMatcher(QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_initialize_1native__Lio_qt_core_QByteArrayMatcher_2Lio_qt_core_QByteArray_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject pattern0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArrayMatcher::QByteArrayMatcher(QByteArray)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = pattern0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArrayMatcher_cref_QByteArray, sizeof(QByteArrayMatcher), typeid(QByteArrayMatcher), false, &deleter_QByteArrayMatcher, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QByteArrayMatcher(QByteArrayMatcher)
void __qt_construct_QByteArrayMatcher_cref_QByteArrayMatcher(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QByteArrayMatcher(QByteArrayMatcher)")
    jobject other0 = __java_arguments[0].l;
    const QByteArrayMatcher& __qt_other0 = qtjambi_cast<const QByteArrayMatcher& >(__jni_env, other0);
    QByteArrayMatcher *__qt_this = new(__qtjambi_ptr) QByteArrayMatcher(__qt_other0);
    if(__qtjambi_is_generic){

        Java::QtJambi::ReferenceUtility::copyReferenceCount(__jni_env, __jni_object, nullptr, __jni_env->NewStringUTF("__rcData"), other0);
    }
    Q_UNUSED(__qt_this)
}

// QByteArrayMatcher::QByteArrayMatcher(QByteArrayMatcher)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_initialize_1native__Lio_qt_core_QByteArrayMatcher_2Lio_qt_core_QByteArrayMatcher_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArrayMatcher::QByteArrayMatcher(QByteArrayMatcher)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArrayMatcher_cref_QByteArrayMatcher, sizeof(QByteArrayMatcher), typeid(QByteArrayMatcher), false, &deleter_QByteArrayMatcher, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QByteArrayMatcher(const char*,int)
void __qt_construct_QByteArrayMatcher_const_char_ptr_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QByteArrayMatcher(const char*,int)")
    size_t length1 = 0;
    jstring pattern0 = static_cast<jstring>(__java_arguments[0].l);
    JBufferConstData __qt_pattern0_buffer(__jni_env, pattern0);
    const char* __qt_pattern0 = __qt_pattern0_buffer.data<char>();
    length1 = __qt_pattern0_buffer.size<char>();
    QByteArrayMatcher *__qt_this = new(__qtjambi_ptr) QByteArrayMatcher(__qt_pattern0, static_cast<int>(length1));
    if(__qtjambi_is_generic){
        Java::QtJambi::ReferenceUtility::setReferenceCount(__jni_env, __jni_object, nullptr, __jni_env->NewStringUTF("__rcData"), false, false, pattern0);
    }
    Q_UNUSED(__qt_this)
}

// QByteArrayMatcher::QByteArrayMatcher(const char*,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_initialize_1native__Lio_qt_core_QByteArrayMatcher_2Ljava_nio_ByteBuffer_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring pattern0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArrayMatcher::QByteArrayMatcher(const char*,int)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = pattern0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArrayMatcher_const_char_ptr_int, sizeof(QByteArrayMatcher), typeid(QByteArrayMatcher), false, &deleter_QByteArrayMatcher, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QByteArrayMatcher
void __qt_destruct_QByteArrayMatcher(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QByteArrayMatcher")
    reinterpret_cast<QByteArrayMatcher*>(ptr)->~QByteArrayMatcher();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QByteArrayMatcher::indexIn(QByteArray,int)const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_indexIn_1native_1cref_1QByteArray_1int_1constfct__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID ba0,
 jint from1)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::indexIn(QByteArray,int)const", __qt_this)
        const QByteArray& __qt_ba0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(ba0);
        __java_return_value = __qt_this->indexIn(__qt_ba0, static_cast<int>(from1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArrayMatcher::operator=(QByteArrayMatcher)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_assign_1native_1cref_1QByteArrayMatcher__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::operator=(QByteArrayMatcher)", __qt_this)
        const QByteArrayMatcher& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QByteArrayMatcher>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QByteArrayMatcher::operator==(QByteArrayMatcher,QByteArrayMatcher)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_equals_1native_1cref_1QByteArrayMatcher__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::operator==(QByteArrayMatcher,QByteArrayMatcher)", __qt_this)
        const QByteArrayMatcher& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QByteArrayMatcher>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArrayMatcher::pattern()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_pattern_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::pattern()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->pattern();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArrayMatcher::setPattern(QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_setPattern_1native_1cref_1QByteArray__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pattern0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArrayMatcher::setPattern(QByteArray)", __qt_this)
        const QByteArray& __qt_pattern0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(pattern0);
        __qt_this->setPattern(__qt_pattern0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArrayMatcher_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QByteArrayMatcher *__qt_this = QtJambiAPI::objectFromNativeId<QByteArrayMatcher>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QByteArrayMatcher(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QByteArrayMatcher>("QByteArrayMatcher", "io/qt/core/QByteArrayMatcher");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QByteArrayMatcher, {
        ConstructorInfo(&__qt_construct_QByteArrayMatcher, nullptr)
       ,ConstructorInfo(&__qt_construct_QByteArrayMatcher_cref_QByteArray, "Lio/qt/core/QByteArray;")
       ,ConstructorInfo(&__qt_construct_QByteArrayMatcher_cref_QByteArrayMatcher, "Lio/qt/core/QByteArrayMatcher;")
       ,ConstructorInfo(&__qt_construct_QByteArrayMatcher_const_char_ptr_int, "Ljava/nio/ByteBuffer;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QByteArrayMatcher);
    registerMetaType<QByteArrayMatcher>("QByteArrayMatcher");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
